==> portal-contribuinte-3.326.0.zip: BOOT-INF/classes/br/com/elotech/tributos/repository/integracaofintelsgo/find-cancelamento-fintel-sgo.sql <==
	select tcd.entidade,
	       TCD.DATACANCELAMENTO,
	       tdpr.Exercicio,
	       tdpr.EXERCICIO AS EXERCICIOREFERENCIA,
	       '04' AS TIPOPAGTO,
	       tdpr.TipoCadastro,
	       tdpr.CadastroGeral,
	       tdpr.GuiaRecolhimento,
	       tdpr.SubDivida,
	       tdpr.Parcela AS PARCELAORIGINAL,
	       tdpr.Parcela AS PARCELA,
	       NULL AS ExercicioLote,
	       NULL AS LOTE,
	       NULL AS LOTEPREF,
	       NULL AS SEQUENCIALOTE,
	       TCD.DATACANCELAMENTO AS DataPagamento,
	       TCD.DATACANCELAMENTO AS DATAMOVIMENTO,
	       TDP.SITUACAOLEGAL AS SITUACAOBAIXA,
	       NULL AS ContaBancaria,
	       NULL AS ContaBancaria_Descr,
	       NULL AS banco,
	       NULL AS agencia,
	       NULL AS ocorrencia,
	       NULL AS Tipobloqueto,
	       NULL AS nossonumero,
	       NULL AS CodigoBarras,
	       TD.PARCELADO AS TIPODEBITO,
	       TAIF.AUTOINFRACAOFISCAL,
	       TAIF.EXERCICIO AS EXERCICIOAUTOINFRACAO,
	       NULL AS idacertopagamento,
	       ' ' AS TIPODOCUMENTO,
	       COMPLETASTRING((CASE WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 101) THEN '01'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 102) THEN '02'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 103) THEN '03'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 104) THEN '04'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 105) THEN '05'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 106) THEN '06'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 107) THEN '07'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 108) THEN '08'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 109) THEN '09'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 110) THEN '10'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 111) THEN '11'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 112) THEN '12'
	            WHEN tdpr.GUIARECOLHIMENTO IN (41, 91, 93, 94) THEN
	              CASE WHEN EXTRACT(MONTH FROM tdp.DATAVENCIMENTO) = 1 THEN '12'
	              ELSE CAST((EXTRACT(MONTH FROM tdp.DATAVENCIMENTO) - 1) AS VARCHAR(2)) END
	            WHEN (tdpr.GUIARECOLHIMENTO = 92) THEN ''
	            WHEN tdpr.GUIARECOLHIMENTO = 62 THEN
	              CASE WHEN EXTRACT(MONTH FROM tdp.DATAVENCIMENTO) = 1 THEN '12'
	              ELSE CAST((EXTRACT(MONTH FROM tdp.DATAVENCIMENTO) - 1) AS VARCHAR(2))
	       END END),'0','E','2') AS MESREFERENCIA,
	       'A' AS SISTEMAGERACAO,
	       CASE WHEN TCDI.IDCANCELAMENTO IS NULL THEN ''
	       ELSE COMPLETASTRING(CAST(TCDI.ENTIDADE AS VARCHAR(2)), '0', 'E', '2') ||TCDI.EXERCICIO||COMPLETASTRING(CAST(TCDI.IDCANCELAMENTO AS VARCHAR(10)),'0','E','10')||COMPLETASTRING(substring(CAST(TDPR.EXERCICIO AS VARCHAR(4)),3,2),'0','E','2')|| COMPLETASTRING(CAST(TDPR.TIPOCADASTRO AS VARCHAR(2)),'0','E','2')|| COMPLETASTRING(CAST(TDPR.CADASTROGERAL AS VARCHAR(10)),'0','E','10')||COMPLETASTRING(CAST(TDPR.GUIARECOLHIMENTO AS VARCHAR(3)),'0','E','3')||COMPLETASTRING(CAST(CASE WHEN TDPR.SUBDIVIDA >= 1000 THEN 999 ELSE TDPR.SUBDIVIDA END  AS VARCHAR(3)),'0','E','3')||COMPLETASTRING(CAST(TDPR.PARCELA AS VARCHAR(4)),'0','E','4') END
	       as CHAVEPAGAMENTOAISE,
	       NULL AS CODIGODAS,
	       NULL as CodigoGuiaISSe,
	       0 AS VALORMULTA,
	       0 AS VALORJUROS,
	       0 AS VALORCORRECAO,
	       SUM(TCDI.VALOR) AS VALORPAGO,
	       SUM(TCDI.VALOR) AS VALORPRINCIPAL
	FROM TRIBCANCELAMENTODEBITO TCD
	   LEFT OUTER JOIN TRIBCANCELAMENTODEBITOITEM TCDI
	             ON TCDI.ENTIDADE = TCD.ENTIDADE
	             AND TCDI.EXERCICIO = TCD.EXERCICIO
	             AND TCDI.IDCANCELAMENTO = TCD.IDCANCELAMENTO
	  LEFT OUTER JOIN TRIBDEBITOPARCELARECEITA TDPR
	             ON TDPR.IDDEBITOPARCELARECEITA = TCDI.IDDEBITOPARCELARECEITA
	  Left outer join tribDebitoParcela tdp on
	       tdp.entidade = tdpr.entidade and
	       tdp.exercicio = tdpr.exercicio and
	       tdp.tipocadastro = tdpr.tipocadastro and
	       tdp.cadastrogeral = tdpr.cadastrogeral and
	       tdp.guiarecolhimento = tdpr.guiarecolhimento and
	       tdp.subdivida = tdpr.subdivida and
	       tdp.parcela = tdpr.parcela
	   LEFT OUTER JOIN TRIBAUTOINFRACAODEBITO TAID
	            ON TAID.ENTIDADE = TDp.ENTIDADE
	           AND TAID.EXERCICIO = TDp.EXERCICIO
	           AND TAID.TIPOCADASTRO = TDp.TIPOCADASTRO
	           AND TAID.CADASTROGERAL = TDp.CADASTROGERAL
	           AND TAID.GUIARECOLHIMENTO = TDp.GUIARECOLHIMENTO
	           AND TAID.SUBDIVIDA = TDp.SUBDIVIDA
	   LEFT OUTER JOIN TRIBAUTOINFRACAOFISCAL TAIF
	            ON TAIF.IDAUTOINFRACAOFISCAL = TAID.IDAUTOINFRACAOFISCAL
	   LEFT OUTER JOIN TRIBDEBITO TD ON
	          tdp.entidade = td.entidade and
	          tdp.exercicio = td.exercicio and
	          tdp.tipocadastro = td.tipocadastro and
	          tdp.cadastrogeral = td.cadastrogeral and
	          tdp.guiarecolhimento = td.guiarecolhimento and
	          tdp.subdivida = td.subdivida
	   LEFT OUTER JOIN TRIBCADASTROGERAL TCG ON
	         td.TipoCadastro = tcg.TipoCadastro and
	         td.CadastroGeral = tcg.CadastroGeral
	:filtrocancelamentos
	      AND TD.GUIARECOLHIMENTO IN (3, 5, 6, 7, 8, 9, 10, 15, 16, 17, 18, 23, 24, 26, 27, 28, 29, 30 ,31, 33, 35, 36, 37, 41, 44, 45, 49, 56, 62, 91, 92, 93, 94, 98, 101, 105,132,152)
	      AND NOT EXISTS(
	          SELECT SUM(TD_ISENCAO.VALORRECEITA), SUM(TD_ISENCAO.VALORRENUNCIA) FROM TRIBDEBITORECEITA TD_ISENCAO
	          WHERE TD_ISENCAO.ENTIDADE = TDP.ENTIDADE
	          AND  TD_ISENCAO.EXERCICIO = TDP.EXERCICIO
	          AND  TD_ISENCAO.TIPOCADASTRO = TDP.TIPOCADASTRO
	          AND  TD_ISENCAO.CADASTROGERAL = TDP.CADASTROGERAL
	          AND  TD_ISENCAO.GUIARECOLHIMENTO = TDP.GUIARECOLHIMENTO
	          AND  TD_ISENCAO.SUBDIVIDA = TDP.SUBDIVIDA
	         HAVING (SUM(TD_ISENCAO.VALORRECEITA) - SUM(TD_ISENCAO.VALORRENUNCIA) = 0)
	            AND NOT (SUM(TD_ISENCAO.VALORRECEITA) = 0 AND SUM(TD_ISENCAO.VALORRENUNCIA) = 0))
	group by
	       tcd.entidade,
	       TCD.DATACANCELAMENTO,
	       tdpr.Exercicio,
	       tdpr.TipoCadastro,
	       tdpr.CadastroGeral,
	       tdpr.GuiaRecolhimento,
	       tdpr.SubDivida,
	       tdpr.Parcela,
	       TCD.DATACANCELAMENTO,
	       TDP.SITUACAOLEGAL,
	       TD.PARCELADO,
	       TAIF.AUTOINFRACAOFISCAL,
	       TAIF.EXERCICIO,
	       COMPLETASTRING((CASE WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 101) THEN '01'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 102) THEN '02'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 103) THEN '03'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 104) THEN '04'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 105) THEN '05'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 106) THEN '06'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 107) THEN '07'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 108) THEN '08'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 109) THEN '09'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 110) THEN '10'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 111) THEN '11'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 112) THEN '12'
	            WHEN tdpr.GUIARECOLHIMENTO IN (41, 91, 93, 94) THEN
	              CASE WHEN EXTRACT(MONTH FROM tdp.DATAVENCIMENTO) = 1 THEN '12'
	              ELSE CAST((EXTRACT(MONTH FROM tdp.DATAVENCIMENTO) - 1) AS VARCHAR(2)) END
	            WHEN (tdpr.GUIARECOLHIMENTO = 92) THEN ''
	            WHEN tdpr.GUIARECOLHIMENTO = 62 THEN
	              CASE WHEN EXTRACT(MONTH FROM tdp.DATAVENCIMENTO) = 1 THEN '12'
	              ELSE CAST((EXTRACT(MONTH FROM tdp.DATAVENCIMENTO) - 1) AS VARCHAR(2))
	       END END),'0','E','2'),
	       CASE WHEN TCDI.IDCANCELAMENTO IS NULL THEN ''
	       ELSE COMPLETASTRING(CAST(TCDI.ENTIDADE AS VARCHAR(2)), '0', 'E', '2') ||TCDI.EXERCICIO||COMPLETASTRING(CAST(TCDI.IDCANCELAMENTO AS VARCHAR(10)),'0','E','10')||COMPLETASTRING(substring(CAST(TDPR.EXERCICIO AS VARCHAR(4)),3,2),'0','E','2')|| COMPLETASTRING(CAST(TDPR.TIPOCADASTRO AS VARCHAR(2)),'0','E','2')|| COMPLETASTRING(CAST(TDPR.CADASTROGERAL AS VARCHAR(10)),'0','E','10')||COMPLETASTRING(CAST(TDPR.GUIARECOLHIMENTO AS VARCHAR(3)),'0','E','3')||COMPLETASTRING(CAST(CASE WHEN TDPR.SUBDIVIDA >= 1000 THEN 999 ELSE TDPR.SUBDIVIDA END  AS VARCHAR(3)),'0','E','3')||COMPLETASTRING(CAST(TDPR.PARCELA AS VARCHAR(4)),'0','E','4') END
	ORDER BY TCD.DATACANCELAMENTO,
	          tdpr.TipoCadastro,
	          tdpr.CadastroGeral,
	          tdpr.GuiaRecolhimento,
	          tdpr.SubDivida,
	          tdpr.Parcela

==> portal-contribuinte-4.106.0.zip: BOOT-INF/classes/br/com/elotech/tributos/repository/integracaofintelsgo/find-cancelamento-fintel-sgo.sql <==
	select tcd.entidade,
	       TCD.DATACANCELAMENTO as databaixa,
	       tdpr.Exercicio,
	       tdpr.EXERCICIO AS EXERCICIOREFERENCIA,
	       '04' AS TIPOPAGTO,
	       'N' as TIPOOPERACAO,
	       tdpr.TipoCadastro,
	       tdpr.CadastroGeral,
	       tdpr.GuiaRecolhimento,
	       tdpr.SubDivida,
	       tdpr.Parcela AS PARCELAORIGINAL,
	       tdpr.Parcela AS PARCELA,
	       NULL AS ExercicioLote,
	       NULL AS LOTE,
	       NULL AS LOTEPREF,
	       NULL AS SEQUENCIALOTE,
	       TCD.DATACANCELAMENTO AS DataPagamento,
	       TCD.DATACANCELAMENTO AS DATAMOVIMENTO,
	       TDP.SITUACAOLEGAL AS SITUACAOBAIXA,
	       NULL AS ContaBancaria,
	       NULL AS ContaBancariaDescr,
	       NULL AS banco,
	       NULL AS agencia,
	       NULL AS ocorrencia,
	       NULL AS Tipobloqueto,
	       NULL AS nossonumero,
	       NULL AS CodigoBarras,
	       TD.PARCELADO AS TIPODEBITO,
	       TAIF.AUTOINFRACAOFISCAL,
	       TAIF.EXERCICIO AS EXERCICIOAUTOINFRACAO,
	       NULL AS idacertopagamento,
	       ' ' AS TIPODOCUMENTO,
	       COMPLETASTRING((CASE WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 101) THEN '01'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 102) THEN '02'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 103) THEN '03'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 104) THEN '04'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 105) THEN '05'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 106) THEN '06'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 107) THEN '07'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 108) THEN '08'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 109) THEN '09'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 110) THEN '10'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 111) THEN '11'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 112) THEN '12'
	            WHEN tdpr.GUIARECOLHIMENTO IN (41, 91, 93, 94) THEN
	              CASE WHEN EXTRACT(MONTH FROM tdp.DATAVENCIMENTO) = 1 THEN '12'
	              ELSE CAST((EXTRACT(MONTH FROM tdp.DATAVENCIMENTO) - 1) AS VARCHAR(2)) END
	            WHEN (tdpr.GUIARECOLHIMENTO = 92) THEN ''
	            WHEN tdpr.GUIARECOLHIMENTO = 62 THEN
	              CASE WHEN EXTRACT(MONTH FROM tdp.DATAVENCIMENTO) = 1 THEN '12'
	              ELSE CAST((EXTRACT(MONTH FROM tdp.DATAVENCIMENTO) - 1) AS VARCHAR(2))
	       END END),'0','E','2') AS MESREFERENCIA,
	       'A' AS SISTEMAGERACAO,
	       CASE WHEN TCDI.IDCANCELAMENTO IS NULL THEN ''
	       ELSE COMPLETASTRING(CAST(TCDI.ENTIDADE AS VARCHAR(2)), '0', 'E', '2') ||TCDI.EXERCICIO||COMPLETASTRING(CAST(TCDI.IDCANCELAMENTO AS VARCHAR(10)),'0','E','10')||COMPLETASTRING(substring(CAST(TDPR.EXERCICIO AS VARCHAR(4)),3,2),'0','E','2')|| COMPLETASTRING(CAST(TDPR.TIPOCADASTRO AS VARCHAR(2)),'0','E','2')|| COMPLETASTRING(CAST(TDPR.CADASTROGERAL AS VARCHAR(10)),'0','E','10')||COMPLETASTRING(CAST(TDPR.GUIARECOLHIMENTO AS VARCHAR(3)),'0','E','3')||COMPLETASTRING(CAST(CASE WHEN TDPR.SUBDIVIDA >= 1000 THEN 999 ELSE TDPR.SUBDIVIDA END  AS VARCHAR(3)),'0','E','3')||COMPLETASTRING(CAST(TDPR.PARCELA AS VARCHAR(4)),'0','E','4') END
	       as CHAVEPAGAMENTOAISE,
	       NULL AS CODIGODAS,
	       NULL as CodigoGuiaISSe,
	       0 AS VALORMULTA,
	       0 AS VALORJUROS,
	       0 AS VALORCORRECAO,
	       SUM(TCDI.VALOR) AS VALORPAGO,
	       SUM(TCDI.VALOR) AS VALORPRINCIPAL
	FROM TRIBCANCELAMENTODEBITO TCD
	   LEFT OUTER JOIN TRIBCANCELAMENTODEBITOITEM TCDI
	             ON TCDI.ENTIDADE = TCD.ENTIDADE
	             AND TCDI.EXERCICIO = TCD.EXERCICIO
	             AND TCDI.IDCANCELAMENTO = TCD.IDCANCELAMENTO
	  LEFT OUTER JOIN TRIBDEBITOPARCELARECEITA TDPR
	             ON TDPR.IDDEBITOPARCELARECEITA = TCDI.IDDEBITOPARCELARECEITA
	  Left outer join tribDebitoParcela tdp on
	       tdp.entidade = tdpr.entidade and
	       tdp.exercicio = tdpr.exercicio and
	       tdp.tipocadastro = tdpr.tipocadastro and
	       tdp.cadastrogeral = tdpr.cadastrogeral and
	       tdp.guiarecolhimento = tdpr.guiarecolhimento and
	       tdp.subdivida = tdpr.subdivida and
	       tdp.parcela = tdpr.parcela
	   LEFT OUTER JOIN TRIBAUTOINFRACAODEBITO TAID
	            ON TAID.ENTIDADE = TDp.ENTIDADE
	           AND TAID.EXERCICIO = TDp.EXERCICIO
	           AND TAID.TIPOCADASTRO = TDp.TIPOCADASTRO
	           AND TAID.CADASTROGERAL = TDp.CADASTROGERAL
	           AND TAID.GUIARECOLHIMENTO = TDp.GUIARECOLHIMENTO
	           AND TAID.SUBDIVIDA = TDp.SUBDIVIDA
	   LEFT OUTER JOIN TRIBAUTOINFRACAOFISCAL TAIF
	            ON TAIF.IDAUTOINFRACAOFISCAL = TAID.IDAUTOINFRACAOFISCAL
	   LEFT OUTER JOIN TRIBDEBITO TD ON
	          tdp.entidade = td.entidade and
	          tdp.exercicio = td.exercicio and
	          tdp.tipocadastro = td.tipocadastro and
	          tdp.cadastrogeral = td.cadastrogeral and
	          tdp.guiarecolhimento = td.guiarecolhimento and
	          tdp.subdivida = td.subdivida
	   LEFT OUTER JOIN TRIBCADASTROGERAL TCG ON
	         td.TipoCadastro = tcg.TipoCadastro and
	         td.CadastroGeral = tcg.CadastroGeral
	   WHERE TD.GUIARECOLHIMENTO IN (3, 5, 6, 7, 8, 9, 10, 15, 16, 17, 18, 23, 24, 26, 27, 28, 29, 30 ,31, 33, 35, 36, 37, 41, 44, 45, 49, 56, 62, 91, 92, 93, 94, 98, 101, 105,132,152)
       %s
       AND NOT EXISTS(
	          SELECT 1 FROM TRIBDEBITORECEITA TD_ISENCAO
	          WHERE TD_ISENCAO.ENTIDADE = TDP.ENTIDADE
	          AND  TD_ISENCAO.EXERCICIO = TDP.EXERCICIO
	          AND  TD_ISENCAO.TIPOCADASTRO = TDP.TIPOCADASTRO
	          AND  TD_ISENCAO.CADASTROGERAL = TDP.CADASTROGERAL
	          AND  TD_ISENCAO.GUIARECOLHIMENTO = TDP.GUIARECOLHIMENTO
	          AND  TD_ISENCAO.SUBDIVIDA = TDP.SUBDIVIDA
	         HAVING (SUM(TD_ISENCAO.VALORRECEITA) - SUM(TD_ISENCAO.VALORRENUNCIA) = 0)
	            AND NOT (SUM(TD_ISENCAO.VALORRECEITA) = 0 AND SUM(TD_ISENCAO.VALORRENUNCIA) = 0))
	group by
	       tcd.entidade,
	       TCD.DATACANCELAMENTO,
	       tdpr.Exercicio,
	       tdpr.TipoCadastro,
	       tdpr.CadastroGeral,
	       tdpr.GuiaRecolhimento,
	       tdpr.SubDivida,
	       tdpr.Parcela,
	       TCD.DATACANCELAMENTO,
	       TDP.SITUACAOLEGAL,
	       TD.PARCELADO,
	       TAIF.AUTOINFRACAOFISCAL,
	       TAIF.EXERCICIO,
	       COMPLETASTRING((CASE WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 101) THEN '01'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 102) THEN '02'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 103) THEN '03'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 104) THEN '04'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 105) THEN '05'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 106) THEN '06'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 107) THEN '07'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 108) THEN '08'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 109) THEN '09'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 110) THEN '10'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 111) THEN '11'
	            WHEN (tdpr.GUIARECOLHIMENTO = 91) AND (tdpr.SUBDIVIDA = 112) THEN '12'
	            WHEN tdpr.GUIARECOLHIMENTO IN (41, 91, 93, 94) THEN
	              CASE WHEN EXTRACT(MONTH FROM tdp.DATAVENCIMENTO) = 1 THEN '12'
	              ELSE CAST((EXTRACT(MONTH FROM tdp.DATAVENCIMENTO) - 1) AS VARCHAR(2)) END
	            WHEN (tdpr.GUIARECOLHIMENTO = 92) THEN ''
	            WHEN tdpr.GUIARECOLHIMENTO = 62 THEN
	              CASE WHEN EXTRACT(MONTH FROM tdp.DATAVENCIMENTO) = 1 THEN '12'
	              ELSE CAST((EXTRACT(MONTH FROM tdp.DATAVENCIMENTO) - 1) AS VARCHAR(2))
	       END END),'0','E','2'),
	       CASE WHEN TCDI.IDCANCELAMENTO IS NULL THEN ''
	       ELSE COMPLETASTRING(CAST(TCDI.ENTIDADE AS VARCHAR(2)), '0', 'E', '2') ||TCDI.EXERCICIO||COMPLETASTRING(CAST(TCDI.IDCANCELAMENTO AS VARCHAR(10)),'0','E','10')||COMPLETASTRING(substring(CAST(TDPR.EXERCICIO AS VARCHAR(4)),3,2),'0','E','2')|| COMPLETASTRING(CAST(TDPR.TIPOCADASTRO AS VARCHAR(2)),'0','E','2')|| COMPLETASTRING(CAST(TDPR.CADASTROGERAL AS VARCHAR(10)),'0','E','10')||COMPLETASTRING(CAST(TDPR.GUIARECOLHIMENTO AS VARCHAR(3)),'0','E','3')||COMPLETASTRING(CAST(CASE WHEN TDPR.SUBDIVIDA >= 1000 THEN 999 ELSE TDPR.SUBDIVIDA END  AS VARCHAR(3)),'0','E','3')||COMPLETASTRING(CAST(TDPR.PARCELA AS VARCHAR(4)),'0','E','4') END
	ORDER BY TCD.DATACANCELAMENTO,
	          tdpr.TipoCadastro,
	          tdpr.CadastroGeral,
	          tdpr.GuiaRecolhimento,
	          tdpr.SubDivida,
	          tdpr.Parcela
%s
